@@ -173,7 +173,7 @@ class TestG90Notifications(G90Fixture):
         notifications.close()
         sensor_cb.assert_called_once_with(100, 'Hall')
 
-    async def test_armdisarm_callback(self):
+    async def test_armdisarm_notification_callback(self):
         future = self.loop.create_future()
         armdisarm_cb = MagicMock()
         armdisarm_cb.side_effect = lambda *args: future.set_result(True)
@@ -187,6 +187,21 @@ class TestG90Notifications(G90Fixture):
         notifications.close()
         armdisarm_cb.assert_called_once_with(1)
 
+    async def test_armdisarm_alert_callback(self):
+        future = self.loop.create_future()
+        armdisarm_cb = MagicMock()
+        armdisarm_cb.side_effect = lambda *args: future.set_result(True)
+        notifications = G90DeviceNotifications(
+            armdisarm_cb=armdisarm_cb, sock=self.socket_mock)
+        await notifications.listen()
+        asynctest.set_read_ready(self.socket_mock, self.loop)
+        self.socket_mock.recvfrom.return_value = (
+            b'[208,[2,4,0,0,"","DUMMYGUID",1630876128,0,[""]]]\0',
+            ('mocked', 12345))
+        await asyncio.wait([future], timeout=0.1)
+        notifications.close()
+        armdisarm_cb.assert_called_once_with(1)
+
     async def test_door_open_close_callback(self):
         future = self.loop.create_future()
         door_open_close_cb = MagicMock()
